# Generated by Django 4.0.4 on 2022-05-25 15:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0073_page_latest_revision"),
        ("tests", "0071_alter_customrestaurantimage_file_hash"),
    ]

    operations = [
        migrations.CreateModel(
            name="RevisableModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("text", models.TextField()),
                (
                    "latest_revision",
                    models.ForeignKey(
                        blank=True,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="wagtailcore.revision",
                        verbose_name="latest revision",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="RevisableChildModel",
            fields=[
                (
                    "revisablemodel_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tests.revisablemodel",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("tests.revisablemodel",),
        ),
        migrations.CreateModel(
            name="RevisableGrandChildModel",
            fields=[
                (
                    "revisablechildmodel_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="tests.revisablechildmodel",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("tests.revisablechildmodel",),
        ),
    ]
