# Generated by Django 4.0.4 on 2022-05-12 12:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0072_revisablemodels"),
    ]

    operations = [
        migrations.AddField(
            model_name="revisablechildmodel",
            name="secret_text",
            field=models.TextField(blank=True, default=""),
        ),
    ]
