(()=>{"use strict";var t,e={9893:function(t,e,r){var o,n=this&&this.__extends||(o=function(t,e){return o=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,e){t.__proto__=e}||function(t,e){for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r])},o(t,e)},function(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");function r(){this.constructor=t}o(t,e),t.prototype=null===e?Object.create(e):(r.prototype=e.prototype,new r)});e.__esModule=!0;var i=function(t){function e(){var e=null!==t&&t.apply(this,arguments)||this;return e.modalOnloadHandlers=DOCUMENT_CHOOSER_MODAL_ONLOAD_HANDLERS,e}return n(e,t),e}(r(211).Chooser);window.DocumentChooser=i,window.createDocumentChooser=function(t){return new i(t)}},5311:t=>{t.exports=jQuery}},r={};function o(t){var n=r[t];if(void 0!==n)return n.exports;var i=r[t]={exports:{}};return e[t].call(i.exports,i,i.exports,o),i.exports}o.m=e,t=[],o.O=(e,r,n,i)=>{if(!r){var a=1/0;for(s=0;s<t.length;s++){for(var[r,n,i]=t[s],u=!0,l=0;l<r.length;l++)(!1&i||a>=i)&&Object.keys(o.O).every((t=>o.O[t](r[l])))?r.splice(l--,1):(u=!1,i<a&&(a=i));if(u){t.splice(s--,1);var c=n();void 0!==c&&(e=c)}}return e}i=i||0;for(var s=t.length;s>0&&t[s-1][2]>i;s--)t[s]=t[s-1];t[s]=[r,n,i]},o.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return o.d(e,{a:e}),e},o.d=(t,e)=>{for(var r in e)o.o(e,r)&&!o.o(t,r)&&Object.defineProperty(t,r,{enumerable:!0,get:e[r]})},o.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(t){if("object"==typeof window)return window}}(),o.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e),o.r=t=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},o.j=588,(()=>{var t={588:0};o.O.j=e=>0===t[e];var e=(e,r)=>{var n,i,[a,u,l]=r,c=0;if(a.some((e=>0!==t[e]))){for(n in u)o.o(u,n)&&(o.m[n]=u[n]);if(l)var s=l(o)}for(e&&e(r);c<a.length;c++)i=a[c],o.o(t,i)&&t[i]&&t[i][0](),t[i]=0;return o.O(s)},r=globalThis.webpackChunkwagtail=globalThis.webpackChunkwagtail||[];r.forEach(e.bind(null,0)),r.push=e.bind(null,r.push.bind(r))})();var n=o.O(void 0,[751],(()=>o(9893)));n=o.O(n)})();