section{border-top:1px solid var(--w-color-grey-200);margin-top:2em;padding:0 0 2em}section>h2:first-child{background:var(--w-color-grey-100);font-size:1em;margin:0 0 1em;padding:1em}.icons :after,.icons :before{font-size:2em}.icons .icon{height:1.5em;vertical-align:text-top;width:1.5em}.icons ul{column-count:3}.icons li{margin-bottom:1em}.icons .spinner{position:relative}.timepicker{height:150px}
